#  Copyright (C) 2024
#  ABM, Moscow
#
#  UNPUBLISHED PROPRIETARY MATERIAL.
#  ALL RIGHTS RESERVED.
#
#  Authors: Revva Konstantin <k.revva@abm-jsc.ru>

from detector_connector import DetectorConnector, DetectorAnalyzeResult

from defocus_detector_connector.defocus_settings import DefocusSettings


class DefocusDetectorConnector(DetectorConnector):
    Context = DetectorConnector.Context
    Config = DetectorConnector.Config

    def __init__(self, config: Config, context: Context):
        super().__init__(config=config,
                         context=context,
                         detector_analyze_result_type=DetectorAnalyzeResult,
                         detector_settings_type=DefocusSettings)
